Development
===========

Slash tries to bring a lot of features to the first releases. For starters, the very first usable version (0.0.1) aims at providing basic running support and most of the groundwork needed for the following milestones.

All changes are checked against `Travis <http://travis-ci.org>`_. Before committing you should test against supported versions using ``tox``, as it runs the same job being run by travis. For more information on Slash's internal unit tests see :ref:`unit_testing`.

Development takes place on `github <https://github.com/vmalloc/slash>`_. Feel free to open issues or pull requests, as a lot of the project's success depends on your feedback!

I normally do my best to respond to issues and PRs as soon as possible (hopefully within one day). Don't hesitate to ping me if you don't hear from me - there's a good chance I missed a notification or something similar.

Contributors
============

Special thanks go to these people for taking the time in improving Slash and providing feedback:

* Alon Horev (@alonho)
* Omer Gertel
* Pierre-Luc Tessier Gagné

